@@ -1,5 +1,6 @@
 package Perlanet::Feed;
 
+use 5.10.0;
 use strict;
 use warnings;
 
@@ -60,6 +61,11 @@ has 'modified' => (
   is => 'rw',
 );
 
+has 'max_entries' => (
+  is => 'ro',
+  isa => 'Int',
+);
+
 has 'entries' => (
   isa => 'ArrayRef',
   is => 'rw',
@@ -79,7 +85,8 @@ Returns a string containing the XML for this feed and all its entries
 =cut
 
 sub as_xml {
-  my ($self, $format) = @_;
+  my $self = shift;
+  my ($format) = @_;
 
   my $feed = XML::Feed->new($format);
   $feed->title($self->title);
